@@ -12,12 +12,12 @@ from .KMeans import KMeans
 
 class ClusteringOptimizer:
 	def __init__(
-			self, min_k, max_k, num_jobs=-1, keep_models=False, timeout=None,
-			external_parallelization=True, num_external_jobs=None, num_internal_jobs=None, **kwargs
+			self, min_k, max_k, n_jobs=-1, keep_models=False, timeout=None,
+			external_parallelization=True, n_external_jobs=None, n_internal_jobs=None, **kwargs
 	):
 		self._min_k = min_k
 		self._max_k = max_k
-		self._num_jobs = num_jobs
+		self._n_jobs = n_jobs
 		self._models = None
 		self._kwargs = kwargs
 		self._keep_models = keep_models
@@ -26,8 +26,8 @@ class ClusteringOptimizer:
 		self._silhouette_scores = None
 		self._timeout = timeout
 		self._external_parallelization = external_parallelization
-		self._num_external_jobs = num_external_jobs
-		self._num_internal_jobs = num_internal_jobs
+		self._n_external_jobs = n_external_jobs
+		self._n_internal_jobs = n_internal_jobs
 
 	def fit(self, X, echo=1, raise_timeout=True, y=None):
 		if self._keep_models:
@@ -37,9 +37,9 @@ class ClusteringOptimizer:
 		self._inertias = {}
 		self._silhouette_scores = {}
 
-		def get_scores(k, num_jobs):
+		def get_scores(k, n_jobs):
 			kmeans = KMeans(
-				n_clusters=k, n_jobs=num_jobs, timeout=self._timeout, raise_timeout=raise_timeout, **self._kwargs
+				n_clusters=k, n_jobs=n_jobs, timeout=self._timeout, raise_timeout=raise_timeout, **self._kwargs
 			)
 			kmeans.fit(X=X)
 			if kmeans.timedout:
@@ -51,17 +51,17 @@ class ClusteringOptimizer:
 			else:
 				return k, None, kmeans.inertia, kmeans.distortion, kmeans.silhouette_score
 
-		if self._external_parallelization and self._num_jobs > 1:
+		if self._external_parallelization and self._n_jobs > 1:
 
-			num_ks = self._max_k - self._min_k + 1
-			num_external_jobs = self._num_external_jobs or min(num_ks, self._num_jobs)
-			remaining_jobs = self._num_jobs - num_external_jobs
-			num_internal_jobs = self._num_internal_jobs or max(1, int(round(remaining_jobs / num_ks)))
-			print(f'num_ks = {num_ks} num_external_jobs = {num_external_jobs} num_internal_jobs = {num_internal_jobs}')
+			n_ks = self._max_k - self._min_k + 1
+			n_external_jobs = self._n_external_jobs or min(n_ks, self._n_jobs)
+			n_remaining_jobs = self._n_jobs - n_external_jobs
+			n_internal_jobs = self._n_internal_jobs or max(1, int(round(n_remaining_jobs / n_ks)))
+			print(f'n_ks = {n_ks} n_external_jobs = {n_external_jobs} n_internal_jobs = {n_internal_jobs}')
 
-			processor = Parallel(n_jobs=num_external_jobs, backend='threading', require='sharedmem')
+			processor = Parallel(n_jobs=n_external_jobs, backend='threading', require='sharedmem')
 			result = processor(
-				delayed(get_scores)(k=k, num_jobs=num_internal_jobs)
+				delayed(get_scores)(k=k, n_jobs=n_internal_jobs)
 				for k in iterate(iterable=range(self._max_k, self._min_k - 1, -1), echo_items=True)
 			)
 
@@ -83,8 +83,8 @@ class ClusteringOptimizer:
 			elapsed = 0
 			for k in range(self._max_k, self._min_k - 1, -1):
 				start_time = get_now()
-				progress_bar.show(amount=self._max_k - k, text=f'j={self._num_jobs}, k={k}{error}, t={round(elapsed)}')
-				k, model, inertia, distortion, silhouette_score = get_scores(k=k, num_jobs=self._num_jobs)
+				progress_bar.show(amount=self._max_k - k, text=f'j={self._n_jobs}, k={k}{error}, t={round(elapsed)}')
+				k, model, inertia, distortion, silhouette_score = get_scores(k=k, n_jobs=self._n_jobs)
 				if inertia is not None or distortion is not None or silhouette_score is not None:
 					if self._keep_models:
 						self._models[k] = model
