@@ -375,7 +375,7 @@ class KMeans:
 
 	@property
 	def distortion(self):
-		self._model_dict.get('distortion', None)
+		return self._model_dict.get('distortion', None)
 
 	@property
 	def inertia(self):
