@@ -41,4 +41,4 @@ class SliceTemplate:
 		return DataSlice(data=data, columns=self._columns, rows=self._rows)
 
 	def __and__(self, other):
-		return self.__class__(columns=get_and(self._columns, other._features), rows=get_and(self._rows, other._rows))
+		return self.__class__(columns=get_and(self._columns, other._columns), rows=get_and(self._rows, other._rows))
