@@ -1,4 +1,5 @@
 from pandas import DataFrame as PandasDF
+from pyspark.sql.session import SparkSession
 from pyspark.sql import DataFrame as SparkDF
 from pyspark.sql.types import IntegerType, DateType, StringType
 from pyspark.sql import functions as f
@@ -184,7 +185,25 @@ class NearestFinder:
 		"""
 		if self._mapping is None:
 			self._create_map_function()
-		return self._mapping.copy()
+		return self._mapping
+
+	def to_spark_df(self, spark=None, from_column='from', to_column='to'):
+		"""
+		:rtype: SparkDF
+		"""
+		if spark is None:
+			spark = SparkSession.builder.getOrCreate()
+
+		return spark.createDataFrame(
+			[(key, value) for key, value in self.mapping.items()],
+			[from_column, to_column]
+		)
+
+	def to_pandas_df(self, from_column='from', to_column='to'):
+		"""
+		:rtype: PandasDF
+		"""
+		return PandasDF({from_column: self.mapping.keys(), to_column: self.mapping.values()})
 
 	def map(self, x):
 		if self._function_type == 'dict':
